package com.fs.course.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.course.domain.FsUserCoursePeriodDays;
import com.fs.course.mapper.FsUserCoursePeriodDaysMapper;
import com.fs.course.vo.FsPeriodCountVO;
import com.fs.course.vo.newfs.FsCourseAnalysisCountVO;
import com.fs.store.mapper.FsUserMapper;
import com.fs.store.param.h5.CourseAnalysisParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.course.mapper.FsUserWatchCourseStatisticsMapper;
import com.fs.course.domain.FsUserWatchCourseStatistics;
import com.fs.course.service.IFsUserWatchCourseStatisticsService;

import static org.apache.coyote.http11.Constants.a;

/**
 * 会员看课统计-按课程统计Service业务层处理
 *
 * @author fs
 * @date 2025-06-17
 */
@Service
@AllArgsConstructor
public class FsUserWatchCourseStatisticsServiceImpl extends ServiceImpl<FsUserWatchCourseStatisticsMapper, FsUserWatchCourseStatistics> implements IFsUserWatchCourseStatisticsService {

    private FsUserCoursePeriodDaysMapper fsUserCoursePeriodDaysMapper;

    private FsUserMapper fsUserMapper;

    /**
     * 查询会员看课统计-按课程统计
     *
     * @param id 会员看课统计-按课程统计主键
     * @return 会员看课统计-按课程统计
     */
    @Override
    public FsUserWatchCourseStatistics selectFsUserWatchCourseStatisticsById(Long id)
    {
        return baseMapper.selectFsUserWatchCourseStatisticsById(id);
    }

    /**
     * 查询会员看课统计-按课程统计列表
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 会员看课统计-按课程统计
     */
    @Override
    public List<FsUserWatchCourseStatistics> selectFsUserWatchCourseStatisticsList(FsUserWatchCourseStatistics fsUserWatchCourseStatistics)
    {
        return baseMapper.selectFsUserWatchCourseStatisticsList(fsUserWatchCourseStatistics);
    }

    /**
     * 新增会员看课统计-按课程统计
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 结果
     */
    @Override
    public int insertFsUserWatchCourseStatistics(FsUserWatchCourseStatistics fsUserWatchCourseStatistics)
    {
        return baseMapper.insertFsUserWatchCourseStatistics(fsUserWatchCourseStatistics);
    }

    /**
     * 修改会员看课统计-按课程统计
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 结果
     */
    @Override
    public int updateFsUserWatchCourseStatistics(FsUserWatchCourseStatistics fsUserWatchCourseStatistics)
    {
        return baseMapper.updateFsUserWatchCourseStatistics(fsUserWatchCourseStatistics);
    }

    /**
     * 批量删除会员看课统计-按课程统计
     *
     * @param ids 需要删除的会员看课统计-按课程统计主键
     * @return 结果
     */
    @Override
    public int deleteFsUserWatchCourseStatisticsByIds(Long[] ids)
    {
        return baseMapper.deleteFsUserWatchCourseStatisticsByIds(ids);
    }

    /**
     * 删除会员看课统计-按课程统计信息
     *
     * @param id 会员看课统计-按课程统计主键
     * @return 结果
     */
    @Override
    public int deleteFsUserWatchCourseStatisticsById(Long id)
    {
        return baseMapper.deleteFsUserWatchCourseStatisticsById(id);
    }

    @Override
    public void insertWatchCourseStatistics() {
        // 1、获取统计数据
        // 查询课程相关数据
        List<FsUserWatchCourseStatistics> fsUserWatchCourseStatistics = fsUserCoursePeriodDaysMapper.selectDaysCountList();

        //2、查询统计数据
        List<FsUserWatchCourseStatistics> watchLog = fsUserMapper.selectWatchLogCount();
        List<FsUserWatchCourseStatistics> redPacketLog = fsUserMapper.selectRedPacketLogCount();
        List<FsUserWatchCourseStatistics> answerLog = fsUserMapper.selectAnswerLogCount();
//        List<FsCourseAnalysisCountVO> courseCountList = fsUserMapper.courseAnalysisWatchLog(courseAnalysisParam);
//        List<FsCourseAnalysisCountVO> redPacketCountList = fsUserMapper.courseAnalysisRedPacketCount(courseAnalysisParam);
//        List<FsCourseAnalysisCountVO> answerCountList = fsUserMapper.courseAnalysisAnswerCount(courseAnalysisParam);

        //3、转化为自定义键的map
//        Map<Long, FsCourseAnalysisCountVO> courseMap = courseCountList.stream()
//                .collect(Collectors.toMap(
//                        FsCourseAnalysisCountVO::getVideoId,
//                        Function.identity()
//                ));
//        Map<Long, FsCourseAnalysisCountVO> redPacketMap = redPacketCountList.stream()
//                .collect(Collectors.toMap(
//                        FsCourseAnalysisCountVO::getVideoId,
//                        Function.identity()
//                ));
//        Map<Long, FsCourseAnalysisCountVO> answerMap = answerCountList.stream()
//                .collect(Collectors.toMap(
//                        FsCourseAnalysisCountVO::getVideoId,
//                        Function.identity()
//                ));
        Map<String, FsUserWatchCourseStatistics> watchLogMap = watchLog.stream().collect(Collectors.toMap(k -> String.format("%s-%s-%s", k.getPeriodId(), k.getVideoId(), k.getCompanyUserId()), v -> v));
        Map<String, FsUserWatchCourseStatistics> redPacketLogMap = redPacketLog.stream().collect(Collectors.toMap(k -> String.format("%s-%s-%s", k.getPeriodId(), k.getVideoId(), k.getCompanyUserId()), v -> v));
        Map<String, FsUserWatchCourseStatistics> answerLogMap = answerLog.stream().collect(Collectors.toMap(k -> String.format("%s-%s-%s", k.getPeriodId(), k.getVideoId(), k.getCompanyUserId()), v -> v));





//        //4、处理数据
//        return videoList.stream().map(v -> {
//            FsPeriodCountVO allVO = new FsPeriodCountVO();
//            BeanUtils.copyProperties(v, allVO);
//            allVO.setTitle(v.getVideoName());
//
//            FsCourseAnalysisCountVO countVO = getCourseAnalysisCountVO(v, courseMap, redPacketMap, answerMap);
//            allVO.setCountDetailsVO(countVO);
//            return allVO;
//        }).collect(Collectors.toList());
        for (FsUserWatchCourseStatistics data : fsUserWatchCourseStatistics) {
            FsUserWatchCourseStatistics vo = new FsUserWatchCourseStatistics();
            String key = String.format("%s-%s-%s", data.getPeriodId(), data.getVideoId(), data.getCompanyUserId());
            FsUserWatchCourseStatistics watchLogData = watchLogMap.get(key);
            FsUserWatchCourseStatistics redPacketLogData = redPacketLogMap.get(key);
            FsUserWatchCourseStatistics answerLogData = answerLogMap.get(key);
//            BeanUtils.copyProperties();
        }

    }

    private String buildKey(Long periodId, Long videoId, Long companyUserId) {
        return periodId + "|" + videoId + "|" + companyUserId;  // 使用特殊字符分隔，确保唯一性
    }
}
